@@ -86,6 +86,7 @@ class Lrc(Gtk.Box):
 
         # mv window
         self.mv_window = Gtk.DrawingArea()
+        self.mv_window.connect('draw', self.on_mv_window_redraw)
         self.pack_start(self.mv_window, True, True, 0)
 
         self.update_background(self.lrc_default_background)
@@ -103,9 +104,10 @@ class Lrc(Gtk.Box):
             return True
 
     def set_lrc(self, lrc_txt):
-        self.lrc_background = None
-        self.old_line = 1
+        self.update_background(self.lrc_default_background)
+        self.old_line_num = 1
         self.old_line_iter = None
+        self.old_timestamp = -5
         if lrc_txt is None:
             print('Failed to get lrc')
             self.lrc_buf.set_text(_('No lrc available'))
@@ -122,26 +124,37 @@ class Lrc(Gtk.Box):
         self.lrc_window.get_vadjustment().set_value(0)
 
     def sync_lrc(self, timestamp):
-        if self.lrc_obj is None:
+        if self.lrc_obj is None or len(self.lrc_obj) <= self.old_line_num:
             return
-        line_num = self.old_line + 1
-        if len(self.lrc_obj) > line_num and \
-                timestamp < self.lrc_obj[line_num][0]:
+        # current line, do nothing
+        if self.lrc_obj[self.old_line_num][0] < timestamp and \
+                timestamp < self.lrc_obj[self.old_line_num + 1][0]:
             return
-        if self.old_line >= 0 and self.old_line_iter and \
-                len(self.old_line_iter) == 2:
+
+        line_num = self.old_line_num + 1
+        # remove old highlighted tags
+        if self.old_line_num >= 0 and self.old_line_iter is not None:
             self.lrc_buf.remove_tag(self.highlighted_tag,
-                    *self.old_line_iter)
-        while len(self.lrc_obj) > line_num and \
-                timestamp > self.lrc_obj[line_num][0]:
-            line_num += 1
+                                    *self.old_line_iter)
+
+        # backward seeking
+        if timestamp < self.old_timestamp:
+            while timestamp < self.lrc_obj[line_num][0]:
+                line_num -= 1
+        else:
+        # forward seeking
+            while len(self.lrc_obj) > line_num and \
+                    timestamp > self.lrc_obj[line_num][0]:
+                line_num += 1
         line_num -= 1
+
         iter_start = self.lrc_buf.get_iter_at_line(line_num)
         iter_end = self.lrc_buf.get_iter_at_line(line_num+1)
         self.lrc_buf.apply_tag(self.highlighted_tag, iter_start, iter_end)
         self.lrc_tv.scroll_to_iter(iter_start, 0, True, 0, 0.5)
         self.old_line_iter = (iter_start, iter_end)
-        self.old_line = line_num
+        self.old_line_num = line_num
+        self.old_timestamp = timestamp
 
     def show_mv(self):
         self.lrc_window.hide()
@@ -155,8 +168,8 @@ class Lrc(Gtk.Box):
         self.lrc_window.show_all()
 
     # styles
-    def update_background(self, filepath, error=None):
-        if filepath == self.lrc_background:
+    def update_background(self, filepath):
+        if filepath is None or filepath == self.lrc_background:
             return
         if filepath and os.path.exists(filepath):
             self.lrc_background = filepath
@@ -177,3 +190,9 @@ class Lrc(Gtk.Box):
         fore_rgba.parse(self.app.conf['lrc-highlighted-text-color'])
         self.highlighted_tag.props.size_points = self.app.conf['lrc-highlighted-text-size']
         self.highlighted_tag.props.foreground_rgba = fore_rgba
+
+    def on_mv_window_redraw(self, *args):
+        if self.app.player.get_fullscreen():
+            self.app.player.playbin.expose_fullscreen()
+        else:
+            self.app.player.playbin.expose()
