@@ -162,7 +162,6 @@ class PlayList(Gtk.Box):
         # control cache job
         self.cache_enabled = False
         self.cache_job = None
-        self.cache_timeout = 0
 
         self.playlist_menu = Gtk.Menu()
         self.playlist_advice_disname = ''
@@ -201,17 +200,20 @@ class PlayList(Gtk.Box):
         toolbar.props.icon_size = 1
         add_btn = Gtk.ToolButton()
         add_btn.set_name('Add')
+        add_btn.set_tooltip_text(_('Add a new playlist'))
         add_btn.set_icon_name('list-add-symbolic')
         add_btn.connect('clicked', self.on_add_playlist_button_clicked)
         toolbar.insert(add_btn, 0)
         remove_btn = Gtk.ToolButton()
         remove_btn.set_name('Remove')
+        remove_btn.set_tooltip_text(_('Remove selected playlist'))
         remove_btn.set_icon_name('list-remove-symbolic')
         remove_btn.connect('clicked', 
                 self.on_remove_playlist_button_clicked)
         toolbar.insert(remove_btn, 1)
         export_btn = Gtk.ToolButton()
         export_btn.set_name('Export')
+        export_btn.set_tooltip_text(_('Export songs in selected playlist'))
         export_btn.set_icon_name('media-eject-symbolic')
         export_btn.connect('clicked', 
                 self.on_export_playlist_button_clicked)
@@ -432,28 +434,14 @@ class PlayList(Gtk.Box):
 
     # song cache daemon
     def switch_caching_daemon(self, *args):
-        print('switch caching daemon')
         if self.cache_enabled is False:
             self.cache_enabled = True
             self.button_start.set_label(_('Stop Cache Service'))
-            self.cache_timeout = GLib.timeout_add(3000,
-                    self.start_cache_daemon)
+            self.do_cache_song_pool()
         else:
-            #if self.cache_job:
-                #self.cache_job.destroy()
             self.cache_enabled = False
-            if self.cache_timeout > 0:
-                GLib.source_remove(self.cache_timeout)
             self.button_start.set_label(_('Start Cache Service'))
 
-    def start_cache_daemon(self):
-        if self.cache_enabled:
-            if self.cache_job is None:
-                self.do_cache_song_pool()
-            return True
-        else:
-            return False
-
     def do_cache_song_pool(self):
         def _move_song():
             self.append_cached_song(song)
@@ -462,7 +450,12 @@ class PlayList(Gtk.Box):
             except IndexError:
                 pass
             Gdk.Window.process_all_updates()
-        def _failed_to_download(song_path, status):
+
+        def _on_can_play(widget, song_path, status, error=None):
+            if status == 'OK':
+                return
+
+            # stop cache service when error occurs
             self.cache_enabled = False
             if status == 'URLError':
                 Widgets.network_error(self.app.window,
@@ -470,22 +463,20 @@ class PlayList(Gtk.Box):
             elif status == 'FileNotFoundError':
                 Widgets.filesystem_error(self.app.window, song_path)
 
-        def _on_can_play(widget, song_path, status, error=None):
-            if status == 'OK':
-                return
-            GLib.idle_add(_failed_to_download, song_path, status)
-
         def _on_downloaded(widget, song_path, error=None):
-            self.cache_job = None
             if song_path:
                 GLib.idle_add(_move_song)
-                return
+            if self.cache_enabled is True:
+                GLib.idle_add(self.do_cache_song_pool)
+
+        if self.cache_enabled is False:
+            return
 
         list_name = 'Caching'
         liststore = self.tabs[list_name].liststore
         path = 0
         if len(liststore) == 0:
-            print('Caching playlist is empty, please add some')
+            print('Caching playlist is empty, please add some songs')
             self.switch_caching_daemon()
             Notify.init('kwplayer-cache')
             notify = Notify.Notification.new('Kwplayer',
