@@ -4,10 +4,10 @@
 # Use of this source code is governed by GPLv3 license that can be found
 # in the LICENSE file.
 
+from gi.repository import Gdk
 from gi.repository import GObject
 from gi.repository import Gst
 from gi.repository import GstVideo
-
 from gi.repository import Gtk
 
 # Or init threads in another place.
@@ -35,6 +35,9 @@ class PlayerBin(GObject.GObject):
     def __init__(self):
         super().__init__()
         self.playbin = Gst.ElementFactory.make('playbin', None)
+        screen = Gdk.Screen.get_default()
+        self.fullscreen_rect = (0, 0, screen.width(), screen.height())
+        
         if self.playbin is None:
             print('Gst Error: playbin failed to inited, abort!')
             sys.exit(1)
@@ -136,8 +139,6 @@ class PlayerBin(GObject.GObject):
     # private functions
     def enable_bus_sync(self):
         self.bus.enable_sync_message_emission()
-        # this signal never emited in gtk3 and gstreamer0.10, it is a bug
-        # found in 2010 and not fixed.
         self.bus_sync_sid = self.bus.connect('sync-message::element', 
                 self.on_sync_message)
 
@@ -148,8 +149,33 @@ class PlayerBin(GObject.GObject):
             self.bus_sync_sid = 0
 
     def on_sync_message(self, bus, msg):
+        if msg.get_structure() is None:
+            return
         if msg.get_structure().get_name() == 'prepare-window-handle':
             msg.src.set_window_handle(self.xid)
+            msg.src.handle_events(False)
+            msg.src.set_property('force-aspect-ratio', True)
+
+    def expose(self, rect=None):
+        '''Redraw video frame.
+
+        This should be used when video overlay is resized.
+        '''
+        if self.bus_sync_sid == 0:
+            return
+        videosink = self.playbin.props.video_sink
+        if videosink is None:
+            return
+        if rect is None:
+            # reset to default size, used in window mode
+            videosink.set_render_rectangle(0, 0, -1, -1)
+        else:
+            videosink.set_render_rectangle(*rect)
+        videosink.expose()
+
+    def expose_fullscreen(self):
+        '''Redraw when in fullscreen mode'''
+        self.expose(self.fullscreen_rect)
 
     def on_eos(self, bus, msg):
         self.emit('eos', True)
